@@ -14,6 +14,7 @@ Be creative! do whatever you need to do!
 __version__ = "0.1.0"
 import json
 import logging
+import os
 import pickle
 import urllib
 from glob import glob
@@ -89,6 +90,82 @@ class MyBranch(BranchAppDrop):
         return result
 
 
+##
+# @brief LengthCheck
+#
+# This branch returns true if the length of the input array is > 0. It also
+# passes the array on to the output ports (will be an empty array in the case
+# of N==0).
+#
+# @par EAGLE_START
+# @param category PythonApp
+# @param[in] param/appclass Application Class/dlg_example_cmpts.apps.LengthCheck/String/readonly/ # noqa: E501
+#     \~English Import direction for application class
+# @param[in] port/array Array/float/
+#     \~English Port receiving the input array
+# @param[out] port/Y Y/float/
+#     \~English Port carrying the array if Y.
+# @param[out] port/N N/float/
+#     \~English Port carrying an empty array (N)
+# @par EAGLE_END
+
+
+class LengthCheck(BranchAppDrop):
+    def initialize(self, **kwargs):
+        BranchAppDrop.initialize(self, **kwargs)
+
+    def readData(self):
+        """
+        Just reading the inoput array and determining the size
+        """
+        input = self.inputs[0]
+        self.raw = droputils.allDropContents(input)
+        data = pickle.loads(self.raw)
+        # make sure we always have a ndarray with at least 1dim.
+        if isinstance(data, np.ndarray):
+            # that's what we want..
+            if data.size == 0:
+                # fix this strange case
+                data = np.array([data])
+                self.raw = pickle.dumps(data)
+        elif not isinstance(data, np.ndarray) and type(data) not in (
+            list,
+            tuple,
+        ):
+            raise TypeError
+        else:
+            # can only be list or tuple. convert those.
+            data = np.array(data)
+            self.raw = pickle.dumps(data)
+
+        self.value = data.size
+
+    def writeData(self):
+        """
+        Write unmodified data to port (self.ind) identified by condition.
+        """
+        output = self.outputs[self.ind]
+        output.len = self.value
+        output.write(self.raw)
+
+    def condition(self):
+        """
+        Check value, call write method and return boolean.
+        """
+        self.readData()
+        if self.value > 0:
+            self.ind = 0
+            result = True
+        else:
+            self.ind = 1
+            result = False
+        self.writeData()
+        return result
+
+    def run(self):
+        self.readData()
+
+
 ##
 # @brief FileGlob
 # @details An App that uses glob to find all files matching a
@@ -129,7 +206,8 @@ class FileGlob(BarrierAppDROP):
 
     def run(self):
         filetmpl = f"{self.filepath}/{self.wildcard}"
-        self.value = glob(filetmpl)
+        files = glob(filetmpl)
+        self.value = [f for f in files if os.path.isfile(f)]
         self.writeData()
 
 
@@ -171,7 +249,7 @@ class PickOne(BarrierAppDROP):
         else:
             data = np.array(data)
         self.value = data[0] if len(data) else None
-        self.rest = data[1:] if len(data) > 1 else []
+        self.rest = data[1:] if len(data) > 1 else np.array([])
 
     def writeData(self):
         """
@@ -342,7 +420,7 @@ class AdvUrlRetrieve(BarrierAppDROP):
 # @param category PythonApp
 # @param/appclass Application Class/dlg_example_cmpts.apps.String2JSON/String/readonly/ # noqa: E501
 #     \~English Import path for application class
-# @param[in] port/string string//string/readwrite/
+# @param[in] port/string string/string/readwrite/
 #     \~English String to be converted
 # @param[out] port/element element/complex/
 #     \~English Port carrying the JSON structure
@@ -399,10 +477,13 @@ class GenericGather(BarrierAppDROP):
 
         inputs = self.inputs
         outputs = self.outputs
+        total_len = 0
+        for input in inputs:
+            total_len += input.len
         for output in outputs:
+            output.len = total_len
             for input in inputs:
                 d = droputils.allDropContents(input)
-                output.len = len(d)
                 output.write(d)
 
     def run(self):
